use strict;
use warnings;

use FindBin;
use lib "$FindBin::Bin/lib";

use MyApp::DB;
use List::Util qw/shuffle/;

my $db = MyApp::DB->new(connect_info => ['dbi:mysql:dbname=myappdb', 'root', '', {
    RaiseError => 1
}]);

$db->txn(sub {
    my $jp = $db->insert_and_emulate_row(country => { name => 'JP', region => 'Asia' });
    my $kr = $db->insert_and_emulate_row(country => { name => 'KR', region => 'Asia' });
    my $cn = $db->insert_and_emulate_row(country => { name => 'CN', region => 'Asia' });
    my $us = $db->insert_and_emulate_row(country => { name => 'US', region => 'NA'   });
    my $ca = $db->insert_and_emulate_row(country => { name => 'CA', region => 'NA'   });
    $db->insert_multi(city => [
        { name => 'Tokyo',      country_id => $jp->id },
        { name => 'Osaka',      country_id => $jp->id },
        { name => 'Beijing',    country_id => $cn->id },
        { name => 'Seoul',      country_id => $kr->id },
        { name => 'California', country_id => $us->id },
        { name => 'Cicago',     country_id => $ca->id },
    ]);

    my @flights;
    my @cities = $db->select(city => {})->all;
    for (1..10) {
        my $departure_city = shuffle @cities;
        my $arrival_city   = shuffle @cities;
        redo if $departure_city->id == $arrival_city->id;

        my $name = sprintf '%s to %s', $departure_city->name, $arrival_city->name;
        push @flights => {
            name              => $name,
            departure_city_id => $departure_city->id,
            arrival_city_id   => $arrival_city->id,
        };
    }

    $db->insert_multi(flight => \@flights);
});
